@@ -43,7 +43,7 @@ TandemBatchProcess::TandemBatchProcess(MainWindow *p_main_window,
   _p_main_window    = p_main_window;
   _tandem_run_batch = tandem_run_batch;
   _p_monitor        = p_monitor;
-  _tmp_database_file.setAutoRemove(true);
+  _tmp_database_file.setAutoRemove(false);
 
   // check that output directory is writeable :
   QFileInfo fi_in_dir(_tandem_run_batch._output_directory);
@@ -427,15 +427,6 @@ TandemBatchProcess::runOne(const QString &mz_file)
           pappso::TandemWrapperRun tandem_run(
             _tandem_run_batch._tandem_bin_path, tmpDirOption);
 
-          std::shared_ptr<pappso::FilterSuite> ms2_filter_suite =
-            std::make_shared<pappso::FilterSuite>();
-
-          ms2_filter_suite.get()->push_back(
-            std::make_shared<pappso::FilterChargeDeconvolution>(
-              pappso::PrecisionFactory::getDaltonInstance(0.01)));
-
-          tandem_run.setMs2FilterSuite(ms2_filter_suite);
-
           tandem_run.run(xml_input_file.fileName(), outputStream, errorStream);
 
 
