@@ -38,6 +38,7 @@
 #include <QDir>
 #include <QFileDialog>
 #include <QMessageBox>
+#include <QInputDialog>
 
 
 EditTandemPresetDialog::EditTandemPresetDialog(QWidget *parent)
@@ -99,6 +100,7 @@ EditTandemPresetDialog::setTandemParametersFile(
         this, tr("Error"), tr("Error :\n %1").arg(error.qwhat()));
     }
 
+  fillPresetDirectoryLabel();
   fillPresetComboBox();
   populate();
 }
@@ -115,6 +117,7 @@ EditTandemPresetDialog::newTandemParameters(
 
   _p_tandem_preset_file =
     new TandemParametersFile(QString("%1/temp.xml").arg(_preset_directory));
+  fillPresetDirectoryLabel();
   fillPresetComboBox();
   populate();
 }
@@ -123,7 +126,23 @@ EditTandemPresetDialog::newTandemParameters(
 void
 EditTandemPresetDialog::doCopy()
 {
-  ui->method_name_line_edit->setText("untitled");
+  bool ok;
+  QString new_preset_file_name =
+    QInputDialog::getText(this,
+                          tr("Preset file name"),
+                          tr("Choose the new preset file name:"),
+                          QLineEdit::Normal,
+                          "untitled",
+                          &ok);
+  if(ok && !new_preset_file_name.isEmpty())
+    {
+      ui->method_name_label->setText(tr("%1 loaded").arg(new_preset_file_name));
+    }
+  else
+    {
+      return;
+    }
+
   readUi();
   if(_p_tandem_preset_file == nullptr)
     {
@@ -135,8 +154,10 @@ EditTandemPresetDialog::doCopy()
     {
       delete _p_tandem_preset_file;
     }
-  _p_tandem_preset_file =
-    new TandemParametersFile(QString("%1/untitled.xml").arg(_preset_directory));
+  qDebug() << new_preset_file_name;
+  _p_tandem_preset_file = new TandemParametersFile(
+    QString("%1/%2.xml").arg(_preset_directory).arg(new_preset_file_name));
+  doSave();
 }
 
 
@@ -160,6 +181,7 @@ EditTandemPresetDialog::doSelectDir()
                   .arg(my_dir.absoluteFilePath()));
             }
           _preset_directory = directory;
+          fillPresetDirectoryLabel();
           fillPresetComboBox();
         }
     }
@@ -281,6 +303,7 @@ EditTandemPresetDialog::fillPresetComboBox()
   int index = ui->preset_combo_box->findText(default_preset_name);
   if(index != -1)
     { // -1 for not found
+      ui->pushButton_5->setEnabled(true);
       ui->preset_combo_box->setCurrentIndex(index);
     }
 }
@@ -649,10 +672,9 @@ EditTandemPresetDialog::doHelp()
     {
       html_doc.setFileName(":/tandem/resources/html_doc/oxp.html");
     }
-  if((senderObjName == "ttcp1_button") || (senderObjName == "ttcp2_button") ||
-     (senderObjName == "ttcp3_button") || (senderObjName == "ttcp4_button"))
+  if(senderObjName == "ttfparam_button")
     {
-      html_doc.setFileName(":/tandem/resources/html_doc/ttcp.html");
+      html_doc.setFileName(":/tandem/resources/html_doc/ttfparam.html");
     }
 
   if(html_doc.open(QFile::ReadOnly | QFile::Text))
@@ -673,7 +695,11 @@ EditTandemPresetDialog::readUi()
 {
   try
     {
-      _tandem_params.setMethodName(ui->method_name_line_edit->text());
+      // remove the loaded from the method name in the label
+      QString temp_preset_name = ui->method_name_label->text();
+      temp_preset_name.truncate(temp_preset_name.lastIndexOf(" loaded"));
+      _tandem_params.setMethodName(temp_preset_name);
+
       _tandem_params.setParamLabelValue(
         "spectrum, parent monoisotopic mass error units", "Daltons");
       if(ui->spmmeu_ppm_radio_button->isChecked())
@@ -747,6 +773,8 @@ EditTandemPresetDialog::readUi()
       _tandem_params.setParamLabelValue("spectrum, threads",
                                         ui->st_edit->text());
 
+      _tandem_params.setParamLabelValue("spectrum, timstof MS2 filters",
+                                        ui->ttfparam_edit->text());
 
       _tandem_params.setParamLabelValue("protein, cleavage site",
                                         ui->pcs_edit->text());
@@ -923,12 +951,6 @@ EditTandemPresetDialog::readUi()
 
       _tandem_params.setParamLabelValue("output, xsl path",
                                         ui->oxp_edit->text());
-      if(ui->centroid_group_box->isChecked())
-        {
-          QString centroid_parameters = createCentroidParameter();
-          _tandem_params.setParamLabelValue(
-            "spectrum, timstof MS2 centroid parameters", centroid_parameters);
-        }
     }
   catch(pappso::PappsoException &error)
     {
@@ -942,7 +964,11 @@ EditTandemPresetDialog::populate()
   qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__;
   try
     {
-      ui->method_name_line_edit->setText(_tandem_params.getMethodName());
+      if(!_tandem_params.getMethodName().isEmpty())
+        {
+          ui->method_name_label->setText(
+            tr("%1 loaded").arg(_tandem_params.getMethodName()));
+        }
       /*
        * <note type="input" label="spectrum, parent monoisotopic mass error
        * units">ppm</note>
@@ -1084,6 +1110,8 @@ EditTandemPresetDialog::populate()
       //<note type="input" label="spectrum, threads">1</note>
       ui->st_edit->setText(_tandem_params.getValue("spectrum, threads"));
 
+      ui->ttfparam_edit->setText(
+        _tandem_params.getValue("spectrum, timstof MS2 filters"));
 
       //<note type="input" label="protein, cleavage site">[RK]|{P}</note>
       ui->pcs_edit->setText(_tandem_params.getValue("protein, cleavage site"));
@@ -1508,26 +1536,6 @@ EditTandemPresetDialog::populate()
       //<note type="input" label="output, path hashing">no</note>
       //<note type="input" label="output, xsl path">tandem-style.xsl</note>
       ui->oxp_edit->setText(_tandem_params.getValue("output, xsl path"));
-
-      try
-        {
-          QStringList centroid_parameters =
-            _tandem_params.getValue("spectrum, timstof MS2 centroid parameters")
-              .split(" ");
-          ui->instru_res_line->setText(centroid_parameters.at(0));
-          ui->smwi_line->setText(centroid_parameters.at(1));
-          ui->intwi_line->setText(centroid_parameters.at(2));
-          ui->intthre_line->setText(centroid_parameters.at(3));
-          ui->centroid_group_box->setChecked(true);
-        }
-      catch(pappso::ExceptionNotFound &error)
-        {
-          ui->instru_res_line->setText("20000");
-          ui->smwi_line->setText("2.0");
-          ui->intwi_line->setText("4");
-          ui->intthre_line->setText("10.0");
-          ui->centroid_group_box->setChecked(false);
-        }
     }
   catch(pappso::ExceptionNotFound &error)
     {
@@ -1548,12 +1556,25 @@ EditTandemPresetDialog::done(int r)
       readUi();
       if(!_p_tandem_preset_file->exists())
         {
-          QMessageBox::warning(
+          int ok = QMessageBox::warning(
             this,
             tr("Save parameters"),
-            tr("Parameters file does not exists.\nPlease save it before "
-               "pressing ok or cancel edition"));
-          return;
+            tr("Parameters file does not exist.\nDo you want to save a file "
+               "named %1")
+              .arg(_p_tandem_preset_file->getMethodName()),
+            QMessageBox::Cancel,
+            QMessageBox::Save);
+
+          if(ok == QMessageBox::Cancel)
+            {
+              return;
+            }
+          else if(ok == QMessageBox::Save)
+            {
+              doSave();
+              QDialog::done(r);
+              return;
+            }
         }
       TandemParameters ref_params =
         _p_tandem_preset_file->getTandemParameters();
@@ -1564,12 +1585,25 @@ EditTandemPresetDialog::done(int r)
         }
       else
         {
-          QMessageBox::warning(
-            this,
-            tr("Save parameters"),
-            tr("Parameters modified but not saved.\nPlease save it before "
-               "pressing ok or cancel edition"));
-          return;
+          int ok =
+            QMessageBox::warning(this,
+                                 tr("Save parameters"),
+                                 tr("Parameters modified but not saved in the "
+                                    "file %1.\nDo you want to save it ?")
+                                   .arg(_p_tandem_preset_file->getMethodName()),
+                                 QMessageBox::Cancel,
+                                 QMessageBox::Save);
+
+          if(ok == QMessageBox::Cancel)
+            {
+              return;
+            }
+          else if(ok == QMessageBox::Save)
+            {
+              doSave();
+              QDialog::done(r);
+              return;
+            }
         }
     }
   else // cancel, close or exc was pressed
@@ -1579,30 +1613,18 @@ EditTandemPresetDialog::done(int r)
     }
 }
 
-QString
-EditTandemPresetDialog::createCentroidParameter()
+void
+EditTandemPresetDialog::fillPresetDirectoryLabel()
 {
-  QString centroid_parameter;
-  bool instru_bool;
-  ui->instru_res_line->text().toDouble(&instru_bool);
-  bool intwi_bool;
-  ui->intwi_line->text().toDouble(&intwi_bool);
-  bool smowi_bool;
-  ui->smwi_line->text().toDouble(&smowi_bool);
-  bool intthre_bool;
-  ui->intthre_line->text().toDouble(&intthre_bool);
-  if(instru_bool && intwi_bool && smowi_bool && intthre_bool)
+  if(!_preset_directory.isEmpty())
     {
-      centroid_parameter =
-        ui->instru_res_line->text() + " " + ui->smwi_line->text() + " " +
-        ui->intwi_line->text() + " " + ui->intthre_line->text();
+      if(QFileInfo(_preset_directory).exists() &&
+         QFileInfo(_preset_directory).isDir())
+        {
+          ui->label_loaded_directory->setText(
+            tr("%1 directory selected").arg(_preset_directory));
+          ui->preset_combo_box->setEnabled(true);
+          ui->pushButton->setEnabled(true);
+        }
     }
-  else
-    {
-      throw pappso::PappsoException(
-        tr("At least one of the centroid parameters hasn't right format\n Must "
-           "be Integer or "
-           "Double\nPlease refer to the help page"));
-    }
-  return centroid_parameter;
 }
