@@ -29,11 +29,13 @@
  ******************************************************************************/
 
 #include "workerthread.h"
+
 #include <odsstream/odsdocwriter.h>
 #include <odsstream/tsvoutputstream.h>
 #include <odsstream/odsexception.h>
 #include <pappsomspp/pappsoexception.h>
 #include <QDebug>
+#include <QSettings>
 #include "../output/exportfastafile.h"
 #include "../output/masschroqml.h"
 #include "../output/masschroqprm.h"
@@ -46,8 +48,9 @@
 #include "project_view/projectwindow.h"
 #include "../core/tandem_run/tandembatchprocess.h"
 #include "../core/tandem_run/tandemcondorprocess.h"
+#include "../core/masschroq_run/masschroqbatchprocess.h"
+#include "../core/masschroq_run/masschroqcondorprocess.h"
 #include "../output/ods/xicareasheet.h"
-#include <QSettings>
 
 WorkerThread::WorkerThread(MainWindow *p_main_window)
 {
@@ -138,6 +141,14 @@ WorkerThread::WorkerThread(MainWindow *p_main_window)
           &MainWindow::operateWritingMcqrSpectralCountFile,
           this,
           &WorkerThread::doWritingMcqrSpectralCountFile);
+  connect(this,
+          &WorkerThread::operateWritingMassChroqFileFinished,
+          p_main_window,
+          &MainWindow::doWritingMassChroQmlFileFinished);
+  connect(p_main_window,
+          &MainWindow::operateRunningMassChroq,
+          this,
+          &WorkerThread::doRunningMassChroQ);
   // protic write
   connect(p_main_window,
           &MainWindow::operateWritingProticFile,
@@ -450,6 +461,7 @@ WorkerThread::doWritingMassChroqFile(QString filename,
       output.write(project_sp);
       output.close();
       emit operationFinished();
+      emit operateWritingMassChroqFileFinished(filename);
     }
   catch(pappso::PappsoException &error)
     {
@@ -626,6 +638,43 @@ WorkerThread::doRunningXtandem(TandemRunBatch tandem_run_batch)
   qDebug();
 }
 
+void
+WorkerThread::doRunningMassChroQ(MassChroQRunBatch masschroq_batch_param)
+{
+  try
+    {
+      emit loadingMessage(tr("Running MassChroQ, please wait"));
+      qDebug();
+
+      QSettings settings;
+      bool use_htcondor =
+        settings.value("masschroq/use_htcondor", "false").toBool();
+
+      if(use_htcondor)
+        {
+
+          MassChroQCondorProcess mcq_process(
+            _p_main_window, _p_work_monitor, masschroq_batch_param);
+          mcq_process.run();
+        }
+      else
+        {
+          MassChroQBatchProcess mcq_process(
+            _p_main_window, _p_work_monitor, masschroq_batch_param);
+          mcq_process.run();
+        }
+
+      emit operationFinished();
+    }
+  catch(pappso::PappsoException &error)
+    {
+      qDebug() << error.qwhat();
+      emit operationFailed(
+        tr("Error while running MassChroQ job :\n%1").arg(error.qwhat()));
+    }
+  qDebug();
+}
+
 
 void
 WorkerThread::doWritingFastaFile(QString filename,
@@ -874,10 +923,10 @@ WorkerThread::doCheckMsrunFilePath(ProjectSp msp_project)
 
 void
 WorkerThread::doWriteXicAreaInCsv(QString filename,
+                                  QString project_name,
                                   std::vector<XicBox *> xic_boxs)
 {
   CalcWriterInterface *p_writer = nullptr;
-
   emit loadingMessage(tr("writing TSV files, please wait"));
   QSettings settings;
   QString xic_export_file =
@@ -885,18 +934,18 @@ WorkerThread::doWriteXicAreaInCsv(QString filename,
   p_writer = new TsvDirectoryWriter(filename);
   if(xic_export_file == "both")
     {
-      XicAreaSheet(p_writer, xic_boxs);
+      XicAreaSheet(p_writer, project_name, xic_boxs);
       bool all_data = true;
-      XicAreaSheet(p_writer, xic_boxs, all_data);
+      XicAreaSheet(p_writer, project_name, xic_boxs, all_data);
     }
   else if(xic_export_file == "all")
     {
       bool all_data = true;
-      XicAreaSheet(p_writer, xic_boxs, all_data);
+      XicAreaSheet(p_writer, project_name, xic_boxs, all_data);
     }
   else // xic_export_file == "area"
     {
-      XicAreaSheet(p_writer, xic_boxs);
+      XicAreaSheet(p_writer, project_name, xic_boxs);
     }
   p_writer->close();
   emit exportXicToCsvFinished();
