@@ -181,6 +181,20 @@ XicBox::XicBox(XicWindow *parent) : QWidget(parent), ui(new Ui::XicBox)
           &XicWindow::rtUnitChangeNeeded,
           this,
           &XicBox::onRtUnitChanged);
+
+  /** @brief Handle axis size to move simultaneously in boxs
+   */
+  connect(ui->xic_widget->getRtAxisP(),
+          qOverload<const QCPRange &>(&QCPAxis::rangeChanged),
+          this,
+          &XicBox::doGetNewRtRange);
+  connect(ui->xic_widget->getIntensityAxisP(),
+          qOverload<const QCPRange &>(&QCPAxis::rangeChanged),
+          this,
+          &XicBox::doGetNewIntensityRange);
+  connect(
+    this, &XicBox::fitAxisRangeInXics, _p_xic_window, &XicWindow::doFitAllAxis);
+
 #else
 // Qt4 code
 #endif
@@ -205,6 +219,25 @@ XicBox::~XicBox()
   _xic_thread.wait();
 }
 
+void
+XicBox::rescaleXicWidget(QString axis_name, QCPRange new_range)
+{
+  ui->xic_widget->rescaleOneRange(axis_name, new_range);
+}
+
+void
+XicBox::doGetNewRtRange(QCPRange new_range)
+{
+  emit fitAxisRangeInXics("xAxis", new_range);
+}
+
+void
+XicBox::doGetNewIntensityRange(QCPRange new_range)
+{
+  emit fitAxisRangeInXics("yAxis", new_range);
+}
+
+
 void
 XicBox::onXicWidgetClick(double rt [[maybe_unused]],
                          double intensity [[maybe_unused]])
@@ -513,7 +546,8 @@ XicBox::drawObservedAreaBars(
     }
 
   //   m_observedRatioBars->setPen(QPen(QColor("red")));
-  m_observedAreaBars->setPen(QPen(QColor("yellow")));
+  m_observedAreaBars->setPen(QColor(180, 15, 32, 200));
+  m_observedAreaBars->setBrush(QColor(180, 15, 32, 200));
   //_graph_peak_surface_list.back()->setScatterStyle(QCPScatterStyle::ssDot);
   // observed_intensity->setBrush(QBrush(QColor(170, 255, 0, 0)));
 
@@ -536,11 +570,27 @@ XicBox::drawObservedAreaBars(
 
   if(ticks.size() > 0)
     {
+      for(double &tick : ticks)
+        {
+          tick += 0.1;
+        }
       m_observedAreaBars->setData(ticks, observed_intensity_data);
+      m_observedAreaBars->setWidth(0.6);
+
+      //       QVector<QString> labels;
+      //       for(double tick : ticks)
+      //         {
+      //           labels.push_back(QString::number(tick));
+      //         }
+      //       QSharedPointer<QCPAxisTickerText> textTicker(new
+      //       QCPAxisTickerText); textTicker->addTicks(ticks, labels);
+      //       ui->histo_widget->yAxis->setTicker(textTicker);
       //       m_observedRatioBars->setData(ticks, observed_ratio_data);
 
       ui->histo_widget->yAxis2->setVisible(true);
       ui->histo_widget->yAxis2->setRange(0, sum);
+      ui->histo_widget->yAxis2->setLabel("observed intensity");
+      ui->histo_widget->yAxis2->setLabelPadding(0);
       ui->histo_widget->replot();
     }
   qDebug();
@@ -578,6 +628,8 @@ XicBox::setIsotopeMassList(
     }
   m_theoreticalRatioBars->setName("th. ratio");
   ui->histo_widget->xAxis->setLabel("isotopes");
+  m_theoreticalRatioBars->setPen(QColor(59, 154, 178));
+  m_theoreticalRatioBars->setBrush(QColor(59, 154, 178));
   // ui->histo_widget->yAxis->setLabel("th. ratio");
 
   QVector<double> theoretical_ratio_data;
@@ -605,14 +657,15 @@ XicBox::setIsotopeMassList(
       isotope_name.append(QString(" (%1%)").arg((
         int)(xic_isotope.peptide_natural_isotope_sp.get()->getIntensityRatio() *
              100)));
-      labels << isotope_name;
+      labels << QString::number(
+        xic_isotope.peptide_natural_isotope_sp.get()->getIsotopeNumber());
       ticks << i;
       i++;
     }
-  // QSharedPointer<QCPAxisTickerText> textTicker(new QCPAxisTickerText);
-  // textTicker->addTicks(ticks, labels);
-  // ui->histo_widget->xAxis->setTicker(textTicker);
-  ui->histo_widget->xAxis->setTickLabelRotation(60);
+  QSharedPointer<QCPAxisTickerText> textTicker(new QCPAxisTickerText);
+  textTicker->addTicks(ticks, labels);
+  ui->histo_widget->xAxis->setTicker(textTicker);
+  ui->histo_widget->xAxis->setTickLabelRotation(0);
   // ui->histo_widget->xAxis->setSubTicks(false);
   // ui->histo_widget->xAxis->setTickLength(0, 4);
   // ui->histo_widget->xAxis->setRange(0, 8);
@@ -622,12 +675,18 @@ XicBox::setIsotopeMassList(
 
     ui->histo_widget->xAxis->setTickStep(1);
   */
-
+  for(double &tick : ticks)
+    {
+      tick -= 0.1;
+    }
   m_theoreticalRatioBars->setData(ticks, theoretical_ratio_data);
+  m_theoreticalRatioBars->setWidth(0.6);
 
 
   ui->histo_widget->yAxis->setRange(0, sum);
-  ui->histo_widget->xAxis->setRange(-0.8, _natural_isotope_list.size());
+  ui->histo_widget->yAxis->setLabel("intensity ratio");
+  ui->histo_widget->yAxis->setLabelPadding(0);
+  ui->histo_widget->xAxis->setRange(-0.5, _natural_isotope_list.size() - 0.5);
   ui->histo_widget->replot();
 }
 
