@@ -71,6 +71,8 @@ class XicBox : public QWidget
   std::vector<XicBoxNaturalIsotope> getNaturalIsotopList() const;
   MsRunSp getMsRunSp();
 
+  void rescaleXicWidget(QString axis_name, QCPRange intensity_range);
+
   signals:
   void loadXic(MsRunSp p_msrun,
                std::vector<pappso::pappso_double> mz_list,
@@ -80,6 +82,8 @@ class XicBox : public QWidget
                               unsigned int charge,
                               pappso::PrecisionPtr precision,
                               double minimum_isotope_pattern_ratio);
+  void fitAxisRangeInXics(QString axis_name, QCPRange new_range);
+
   private slots:
   void remove();
   void reExtractXic();
@@ -93,6 +97,8 @@ class XicBox : public QWidget
   void onRtUnitChanged();
   void onXicWidgetClick(double rt, double intensity);
   void onIsotopicDistributionClick();
+  void doGetNewRtRange(QCPRange new_range);
+  void doGetNewIntensityRange(QCPRange new_range);
 
   private:
   void drawObservedAreaBars(
