@@ -213,3 +213,34 @@ XicWindow::doExportXicToCsv()
     }
   emit operateXicAreaToCsv(filename, xic_boxs);
 }
+
+void
+XicWindow::doChangeLockXaxisRule()
+{
+  if(m_lockXaxis)
+    {
+      ui->toolButton->setIcon(
+        QIcon(":/icons/resources/icons/apache/firefox/unlock_icon.svg"));
+      m_lockXaxis = false;
+    }
+  else
+    {
+      ui->toolButton->setIcon(
+        QIcon(":/icons/resources/icons/apache/firefox/lock_icon.svg"));
+      m_lockXaxis = true;
+    }
+}
+
+void
+XicWindow::doFitAllAxis(QString axis_name, QCPRange new_range)
+{
+  if(m_lockXaxis)
+    {
+      for(int i = 0; i < ui->verticalLayout->layout()->count(); i++)
+        {
+          XicBox *p_xic =
+            dynamic_cast<XicBox *>(ui->verticalLayout->itemAt(i)->widget());
+          p_xic->rescaleXicWidget(axis_name, new_range);
+        }
+    }
+}
