@@ -36,6 +36,7 @@
 
 #include "../../core/peptideevidence.h"
 #include "xic_widgets/zivydialog.h"
+#include <qcustomplot.h>
 
 class ProjectWindow;
 
@@ -75,6 +76,8 @@ class XicWindow : public QMainWindow
   void doAcceptedZivyDialog();
   void doXicExtractionMethodChanged(pappso::XicExtractMethod xic_method);
   void doExportXicToCsv();
+  void doChangeLockXaxisRule();
+  void doFitAllAxis(QString axis_name, QCPRange new_range);
 
   signals:
   void reExtractXicNeeded();
@@ -92,7 +95,7 @@ class XicWindow : public QMainWindow
   private:
   ProjectWindow *_project_window;
   Ui::XicWindow *ui;
-
+  bool m_lockXaxis = false;
   std::shared_ptr<pappso::TraceDetectionInterface> msp_detect_zivy;
 
 
